<?php
/*
 * @version $Id: model.class.php 124 2012-07-04 12:29:03Z remi $
 -------------------------------------------------------------------------
 dumpentity - DumpEntity plugin for GLPI
 Copyright (C) 2003-2011 by the dumpentity Development Team.

 https://forge.indepnet.net/projects/dumpentity
 -------------------------------------------------------------------------

 LICENSE

 This file is part of dumpentity.

 dumpentity is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 dumpentity is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with dumpentity. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
*/

// Original Author of file: Remi Collet
// Purpose of file:
// ----------------------------------------------------------------------

if (!defined("PLUGIN_DUMPENTITY_UPLOAD_DIR")){
   define  ("PLUGIN_DUMPENTITY_UPLOAD_DIR",  GLPI_PLUGIN_DOC_DIR."/dumpentity/");
}

class PluginDumpentityModel extends CommonDBTM{

   const LOADENTITY_VERSION_REQUIRE = '1.3.0';
   const DUMPENTIY_DB_SCHEMA        = '1.3';

   static function getTypeName($nb=0) {
      global $LANG;

      if ($nb>1) {
         return $LANG['plugin_dumpentity']['config'][16];
      }
      return $LANG['plugin_dumpentity']['config'][1];
   }


   function canCreate() {
      return Session::haveRight('profile', 'w');
   }


   function canView() {
      return Session::haveRight('profile', 'r');
   }


   function canUpdateItem() {
      // id=1, complete model, is protected
      return $this->fields['id'] > 1;
   }


   function canDeleteItem() {
      // id=1, complete model, is protected
      return $this->fields['id'] > 1;
   }


   function defineTabs($options=array()) {
      global $LANG;

      $ong = array();
      $this->addStandardTab(__CLASS__, $ong, $options);
      $this->addStandardTab('PluginDumpentityProfile', $ong, $options);
      $this->addStandardTab('PluginDumpentityClient', $ong, $options);

      return $ong;
   }


   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
      global $LANG;

      if ($item->getType() == __CLASS__) {
         return $this->getTypeName(1);
      }

      return '';
   }


   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {

      if ($item->getType() == __CLASS__) {
         $item->showTables();
         return true;
      }
      return false;
   }


   function showTables(){
      global $LANG, $DB;

      if (!Session::haveRight("profile","r")) {
         return false;
      }
      $canedit = $this->can($this->getID(), 'w');

      if ($canedit) {
         echo "<form action='".$this->getFormURL()."' method='post'>";
      }
      echo "<table class='tab_cadre' cellpadding='5'>";
      echo "<tr><th colspan='6'>".$LANG['plugin_dumpentity']['config'][3]." '".
            $this->fields["name"]."' </th></tr>";

      $i = 0;
      $tables = self::getTables();
      asort($tables);
      foreach ($tables as $name => $descr) {
         if ($i%3 == 0) {
            echo "<tr class='tab_bg_1'>";
         }
         if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE) {
            echo "<td>$descr<br>($name)&nbsp;: </td><td>";
         } else {
            echo "<td>$descr&nbsp;: </td><td>";
         }
         if ($canedit) {
            Dropdown::showYesNo($name, $this->fields[$name]);
         } else {
            echo Dropdown::getYesNo($this->fields[$name]);
         }
         echo "</td>";

         if ($i%3 == 2) {
            echo "</tr>\n";
         }
         $i++;
      }
      if ($i%3 == 1) {
         echo "<td colspan='4'></tr>\n";
      }
      if ($i%3 == 2) {
         echo "<td colspan='2'></tr>\n";
      }

      if ($canedit) {
         echo "<tr class='tab_bg_1'><td class='center' colspan='6'>";
         echo "<input type='hidden' name='id' value='".$this->fields['id']."'>";
         echo "<input type='submit' name='update' value='".$LANG["buttons"][7]."' class='submit'>";
         echo "&nbsp;&nbsp;<input type='submit' name='delete' value='".$LANG["buttons"][6]."' class='submit'>";
         echo "</td></tr>\n";
      }

      echo "</table>";
      if ($canedit) {
         Html::closeForm();
      }
   }

   function showForUser($gzip) {
      global $LANG;

      echo "<table class='tab_cadre' cellpadding='5'><tr class='tab_bg_1'>";
      echo "<th colspan='4'>" . $this->fields["name"] . "</th></tr>\n";

      if ($gzip) {
         echo "<tr class='tab_bg_2'><td colspan='4' class='center'>";
         echo "<a href='".$_SERVER["PHP_SELF"]."?gzip=0'>".$LANG['plugin_dumpentity']['form'][3]."</a>";
         echo "</td></tr>\n";

      } else if (function_exists("gzopen")) {
         echo "<tr class='tab_bg_2'><td colspan='4' class='center'>";
         echo "<a href='".$_SERVER["PHP_SELF"]."?gzip=1'>".$LANG['plugin_dumpentity']['form'][2]."</a>";
         echo "</td></tr>\n";
      }

      $i = 0;
      $tables = self::getTables();
      asort($tables);

      foreach ($tables as $name => $descr) {
         if ($this->fields[$name]) {
            if ($i%4 == 0) {
               echo "<tr class='tab_bg_1'>";
            }
            echo "<td>&nbsp;<a href='front/getcsv.php?gzip=$gzip&table=$name'>$descr</a>&nbsp;</td>";
            if ($i%4 == 3) {
               echo "</tr>\n";
            }
            $i++;
         }
      }

      if ($i%4) {
         echo "<td colspan='" . (4-($i%4)) . "'>&nbsp;</td></tr>\n";
      }
      if (class_exists("ZipArchive")) {
         echo "<tr class='tab_bg_2'><td colspan='4' class='center'>";
         echo "<a href='front/getzip.php'>".$LANG['plugin_dumpentity']['form'][1]."</a></td></tr>\n";
      }

      $inc = @fopen("Archive/Tar.php", "r", true);
      if ($inc) {
         fclose($inc);
         echo "<tr class='tab_bg_2'><td colspan='4' class='center'>";
         echo "<a href='front/gettgz.php'>".$LANG['plugin_dumpentity']['form'][4]."</a></td></tr>\n";
      }

      echo "</table>";
   }

   function showForm ($ID, $options=array()) {
      global $CFG_GLPI, $LANG;

      if ($ID>0) {
         $this->check($ID, 'r');
      } else {
         $this->check(-1, 'w');
         $this->getEmpty();
      }

      $this->showTabs($options);
      $this->showFormHeader($options);

      echo "<tr class='tab_bg_1'>";
      echo "<td>".$LANG['common'][16]."&nbsp;:</td><td>";
      Html::autocompletionTextField($this, 'name', array('size' => 34));
      echo "</td><td rowspan='2'>".$LANG['common'][25]."&nbsp;:</td>";
      echo "<td rowspan='2'>";
      echo "<textarea cols='45' rows='5' name='comment' >".$this->fields["comment"]."</textarea>";
      echo "</td></tr>";

      echo "<tr class='tab_bg_1'>";
      echo "<td>".$LANG['common'][26]."&nbsp;:</td><td>";
      echo Html::convDateTime($this->fields["date_mod"]);
      echo "</td></tr>";

      if ($ID==1) {
         echo "<tr class='tab_bg_1'><td colspan='4' class='center b'>";
         echo $LANG['plugin_dumpentity']['config'][4];
         echo "</th></td>";
      }

      $this->showFormButtons($options);
      $this->addDivForTabs();
   }

   static function getTables() {
      global $LANG;
      static $tables = NULL;

      if (is_null($tables)) {
         $tables = array(
            'glpi_alerts'                       => $LANG['common'][41],
            // Not exported : glpi_authldapreplicates
            'glpi_authldaps'                    => $LANG['setup'][67] ." / ". $LANG['login'][2],
            'glpi_authmails'                    => $LANG['setup'][67] ." / ". $LANG['login'][3],
            'glpi_autoupdatesystems'            => $LANG['computers'][51],
            'glpi_bookmarks'                    => $LANG['bookmark'][1],
            'glpi_bookmarks_users'              => $LANG['bookmark'][1] ." / ". $LANG['Menu'][14],
            'glpi_budgets'                      => $LANG['financial'][87],
            'glpi_calendars'                    => $LANG['Menu'][42],
            'glpi_calendarsegments'             => $LANG['calendar'][5],
            'glpi_calendars_holidays'           => $LANG['Menu'][42] ." / ". $LANG['calendar'][4],
            'glpi_cartridgeitems'               => $LANG['cartridges'][12],
            'glpi_cartridgeitems_printermodels' => $LANG['cartridges'][12] ." / ". $LANG['Menu'][2],
            'glpi_cartridgeitemtypes'           => $LANG['setup'][84],
            'glpi_cartridges'                   => $LANG['cartridges'][0],
            'glpi_changes'                      => $LANG['change'][0],
            'glpi_changes_groups'               => $LANG['change'][0] ." / ". $LANG['common'][35],
            'glpi_changes_items'                => $LANG['change'][0] ." / ". $LANG['common'][1],
            'glpi_changes_problems'             => $LANG['change'][0] ." / ". $LANG['problem'][0],
            'glpi_changes_tickets'              => $LANG['change'][0] ." / ". $LANG['job'][38],
            'glpi_changes_users'                => $LANG['change'][0] ." / ". $LANG['common'][34],
            'glpi_changetasks'                  => $LANG['change'][0] ." / ". $LANG['job'][7],
            'glpi_computerdisks'                => $LANG['computers'][8],
            'glpi_computermodels'               => $LANG['setup'][91],
            'glpi_computers'                    => $LANG['Menu'][0],
            'glpi_computers_devicecases'        => $LANG['Menu'][0]  ." / ". $LANG['devices'][22],
            'glpi_computers_devicecontrols'     => $LANG['Menu'][0]  ." / ". $LANG['devices'][20],
            'glpi_computers_devicedrives'       => $LANG['Menu'][0]  ." / ". $LANG['devices'][19],
            'glpi_computers_devicegraphiccards' => $LANG['Menu'][0]  ." / ". $LANG['devices'][2],
            'glpi_computers_deviceharddrives'   => $LANG['Menu'][0]  ." / ". $LANG['devices'][1],
            'glpi_computers_devicememories'     => $LANG['Menu'][0]  ." / ". $LANG['devices'][6],
            'glpi_computers_devicemotherboards' => $LANG['Menu'][0]  ." / ". $LANG['devices'][5],
            'glpi_computers_devicenetworkcards' => $LANG['Menu'][0]  ." / ". $LANG['devices'][3],
            'glpi_computers_devicepcis'         => $LANG['Menu'][0]  ." / ". $LANG['devices'][21],
            'glpi_computers_devicepowersupplies'=> $LANG['Menu'][0]  ." / ". $LANG['devices'][23],
            'glpi_computers_deviceprocessors'   => $LANG['Menu'][0]  ." / ". $LANG['devices'][4],
            'glpi_computers_devicesoundcards'   => $LANG['Menu'][0]  ." / ". $LANG['devices'][7],
            'glpi_computers_items'              => $LANG['Menu'][0]  ." / ". $LANG['Menu'][16],
            'glpi_computers_softwarelicenses'   => $LANG['help'][31]  ." / ".$LANG['software'][12],
            'glpi_computers_softwareversions'   => $LANG['software'][17],
            'glpi_computertypes'                => $LANG['setup'][4],
            'glpi_computervirtualmachines'      => $LANG['computers'][57],
            // Not exported : glpi_configs
            'glpi_consumableitems'              => $LANG['Menu'][32],
            'glpi_consumableitemtypes'          => $LANG['setup'][92],
            'glpi_consumables'                  => $LANG['Menu'][32] ." / ". $LANG['consumables'][1],
            'glpi_contacts'                     => $LANG['Menu'][22],
            'glpi_contacts_suppliers'           => $LANG['Menu'][22] ." / ". $LANG['Menu'][23],
            'glpi_contacttypes'                 => $LANG['setup'][82],
            'glpi_contracts'                    => $LANG['Menu'][25],
            'glpi_contracts_items'              => $LANG['Menu'][25] ." / ". $LANG['common'][1],
            'glpi_contracts_suppliers'          => $LANG['Menu'][25] ." / ". $LANG['Menu'][23],
            'glpi_contracttypes'                => $LANG['setup'][85],
            // Not exported : all about crontasks
            'glpi_devicecases'                  => $LANG['devices'][22],
            'glpi_devicecasetypes'              => $LANG['setup'][45],
            'glpi_devicecontrols'               => $LANG['devices'][20],
            'glpi_devicedrives'                 => $LANG['devices'][19],
            'glpi_devicegraphiccards'           => $LANG['devices'][2],
            'glpi_deviceharddrives'             => $LANG['devices'][1],
            'glpi_devicememories'               => $LANG['devices'][6],
            'glpi_devicememorytypes'            => $LANG['setup'][86],
            'glpi_devicemotherboards'           => $LANG['devices'][5],
            'glpi_devicenetworkcards'           => $LANG['devices'][3],
            'glpi_devicepcis'                   => $LANG['devices'][21],
            'glpi_devicepowersupplies'          => $LANG['devices'][23],
            'glpi_deviceprocessors'             => $LANG['devices'][4],
            'glpi_devicesoundcards'             => $LANG['devices'][7],
            // Not exported : glpi_displaypreferences
            'glpi_documentcategories'           => $LANG['setup'][81],
            'glpi_documents'                    => $LANG['Menu'][27],
            'glpi_documents_items'              => $LANG['Menu'][27] ." / ". $LANG['common'][1],
            'glpi_documenttypes'                => $LANG['document'][7],
            'glpi_domains'                      => $LANG['setup'][89],
            'glpi_entities'                     => $LANG['Menu'][37],
            'glpi_entities_reminders'           => $LANG['Menu'][37] ." / ". $LANG['title'][37],
            'glpi_entitydatas'                  => $LANG['Menu'][37] ." / ". $LANG['Menu'][12],
            // Not exported : glpi_events
            // Not exported : glpi_fieldblacklists - glpi_fieldunicities
            'glpi_filesystems'                  => $LANG['computers'][4],
            'glpi_groups'                       => $LANG['Menu'][36],
            'glpi_groups_problems'              => $LANG['Menu'][36] ." / ". $LANG['problem'][0],
            'glpi_groups_reminders'             => $LANG['Menu'][36] ." / ". $LANG['title'][37],
            'glpi_groups_tickets'               => $LANG['Menu'][36] ." / ". $LANG['job'][38],
            'glpi_groups_users'                 => $LANG['Menu'][14] ." / ". $LANG['Menu'][36],
            'glpi_holidays'                     => $LANG['calendar'][4],
            'glpi_infocoms'                     => $LANG['financial'][3],
            'glpi_interfacetypes'               => $LANG['setup'][93],
            'glpi_items_problems'               => $LANG['common'][1] ." / ". $LANG['problem'][0],
            'glpi_itilcategories'               => $LANG['setup'][79],
            'glpi_knowbaseitemcategories'       => $LANG['title'][5] ." / ". $LANG['common'][36],
            'glpi_knowbaseitems'                => $LANG['title'][5],
            'glpi_links'                        => $LANG['title'][34],
            'glpi_links_itemtypes'              => $LANG['title'][34] ." / ". $LANG['state'][6],
            'glpi_locations'                    => $LANG['common'][15],
            // Not exported : glpi_logs
            // Not exported : glpi_mailcollectors - glpi_mailingsettings
            'glpi_manufacturers'                => $LANG['common'][5],
            'glpi_monitormodels'                => $LANG['setup'][94],
            'glpi_monitors'                     => $LANG['Menu'][3],
            'glpi_monitortypes'                 => $LANG['setup'][44],
            'glpi_netpoints'                    => $LANG['networking'][51],
            'glpi_networkequipmentfirmwares'    => $LANG['setup'][71],
            'glpi_networkequipmentmodels'       => $LANG['setup'][95],
            'glpi_networkequipments'            => $LANG['title'][6],
            'glpi_networkequipmenttypes'        => $LANG['setup'][42],
            'glpi_networkinterfaces'            => $LANG['setup'][9],
            'glpi_networkports'                 => $LANG['networking'][6],
            'glpi_networkports_networkports'    => $LANG['networking'][6] ." / ". $LANG['networking'][17],
            'glpi_networkports_vlans'           => $LANG['networking'][6] ." / ". $LANG['networking'][56],
            'glpi_networks'                     => $LANG['setup'][88],
            // Not exported : all about notifications
            // Not exported : glpi_notimportedemails
            // Not exported : all about OCS
            'glpi_operatingsystems'             => $LANG['dropdown'][28],
            'glpi_operatingsystemservicepacks'  => $LANG['computers'][53],
            'glpi_operatingsystemversions'      => $LANG['computers'][52],
            'glpi_peripheralmodels'             => $LANG['setup'][97],
            'glpi_peripherals'                  => $LANG['Menu'][16],
            'glpi_peripheraltypes'              => $LANG['setup'][69],
            'glpi_phonemodels'                  => $LANG['setup'][503],
            'glpi_phonepowersupplies'           => $LANG['setup'][505],
            'glpi_phones'                       => $LANG['help'][35],
            'glpi_phonetypes'                   => $LANG['setup'][504],
            // Not exported : glpi_plugins
            'glpi_printermodels'                => $LANG['setup'][96],
            'glpi_printers'                     => $LANG['Menu'][2],
            'glpi_printertypes'                 => $LANG['setup'][43],
            'glpi_problems'                     => $LANG['problem'][0],
            'glpi_problems_tickets'             => $LANG['problem'][0] ." / ". $LANG['job'][38],
            'glpi_problems_users'               => $LANG['problem'][0] ." / ". $LANG['Menu'][14],
            'glpi_problemtasks'                 => $LANG['problem'][0] ." / ". $LANG['job'][7],
            'glpi_profiles'                     => $LANG['Menu'][35],
            'glpi_profiles_reminders'           => $LANG['Menu'][35] ." / ". $LANG['title'][37],
            'glpi_profiles_users'               => $LANG['Menu'][14] ." / ". $LANG['Menu'][35],
            'glpi_registrykeys'                 => $LANG['ocsconfig'][41],
            'glpi_reminders'                    => $LANG['title'][37],
            'glpi_reminders_users'              => $LANG['title'][37] ." / ". $LANG['Menu'][14],
            // Not exported : glpi_requesttypes
            'glpi_reservationitems'             => $LANG['reservation'][10],
            'glpi_reservations'                 => $LANG['Menu'][17],
            // Not exported : all about rules
            // Not exported : all about slas
            'glpi_softwarecategories'           => $LANG['softwarecategories'][5],
            'glpi_softwarelicenses'             => $LANG['help'][31]." / ".$LANG['install'][92],
            'glpi_softwarelicensetypes'         => $LANG['install'][92]." / ".$LANG['common'][17],
            'glpi_softwares'                    => $LANG['help'][31],
            'glpi_softwareversions'             => $LANG['help'][31]." / ".$LANG['rulesengine'][78],
            // Not exported : glpi_solutiontemplates
            'glpi_solutiontypes'                => $LANG['dropdown'][5],
            'glpi_states'                       => $LANG['setup'][83],
            'glpi_suppliers'                    => $LANG['Menu'][23],
            'glpi_suppliertypes'                => $LANG['setup'][80],
            'glpi_taskcategories'               => $LANG['dropdown'][4],
            'glpi_ticketfollowups'              => $LANG['mailing'][141]. " " .$LANG['Menu'][5],
            'glpi_ticketrecurrents'             => $LANG['jobrecurrent'][1],
            'glpi_tickets'                      => $LANG['Menu'][5],
            'glpi_ticketsatisfactions'          => $LANG['satisfaction'][0],
            'glpi_tickets_tickets'              => $LANG['job'][55],
            'glpi_tickets_users'                => $LANG['Menu'][5]. " " .$LANG['Menu'][14],
            'glpi_tickettasks'                  => $LANG['mailing'][142]." / ".$LANG['Menu'][5],
            'glpi_ticketvalidations'            => $LANG['validation'][0],
            // Not exported : all about tickettemplates
            // Not exported : glpi_transfers
            'glpi_usercategories'               => $LANG['common'][34]." / ".$LANG['common'][36],
            'glpi_useremails'                   => $LANG['mailing'][118],
            'glpi_users'                        => $LANG['Menu'][14],
            'glpi_usertitles'                   => $LANG['common'][34]." / ".$LANG['common'][57],
            // Not exported : all about virtualmachines
            'glpi_vlans'                        => $LANG['setup'][90],
         );
      }
      return $tables;
   }

   static function getCSV($table, $entity, $recursive=0, $gzip=0, $encode='') {
      global $DB, $CFG_GLPI;

      $entity_in = " IN (".($recursive?implode(getSonsOf("glpi_entities", $entity),','):$entity).")";

      // Waiting for 0.70 stable
      if (!isset($CFG_GLPI["networkport_types"])) {
         $CFG_GLPI["networkport_types"] = array('Computer', 'NetworkEquipment', 'Peripheral', 'Phone',
                                                'Printer');
      }

      if (!function_exists("gzopen")) {
         $gzip = 0;
      }

      $Sql = "SELECT *
              FROM `$table` ";

      if ($table == "glpi_entities") {
         $Sql = "SELECT *
                 FROM `$table`
                 WHERE `id` IN ($entity,".implode(getAncestorsOf("glpi_entities", $entity), ', ');
         if ($recursive) {
            //Dump entity + sub entities + entity's parents
            $Sql .= ",".implode(getSonsOf("glpi_entities", $entity),',').')';
         } else {
            $Sql .= ")";
         }

      } else if ($table == "glpi_networkports_networkports") {

         $Sql = "SELECT `$table`.*
                 FROM `glpi_networkports`
                 INNER JOIN `$table` ON (`glpi_networkports`.`id` = `$table`.`networkports_id_2`
                                         OR `glpi_networkports`.`id` = `$table`.`networkports_id_1`)
                 WHERE (`glpi_networkports`.`entities_id` $entity_in)";

      } else if ($table == "glpi_users") {
         $Sql .= " WHERE `name` != 'glpi'
                         AND `id` IN (SELECT DISTINCT(`users_id`)
                                      FROM `glpi_profiles_users`
                                      WHERE (`entities_id` $entity_in
                                             OR (`is_recursive` = '1'
                                                 AND `entities_id`
                                                      IN ".self::parents($entity) .")))";

      } else if (FieldExists($table, "is_recursive")) {
         $Sql .= " WHERE (`entities_id` $entity_in
                          OR (`is_recursive` = '1'
                              AND `entities_id` IN " . self::parents ($entity) ."))";

      } else if (FieldExists($table, "entities_id")) {
         // for most tables
         $Sql .= " WHERE `entities_id` $entity_in";

      } else if (FieldExists($table, "users_id")) {
         // for glpi_useremails
         $Sql .= "WHERE `users_id` IN (SELECT DISTINCT(`users_id`)
                                       FROM `glpi_profiles_users`
                                       WHERE (`entities_id` $entity_in
                                              OR (`is_recursive` = '1'
                                                  AND `entities_id`
                                                       IN ".self::parents($entity) .")))";

      } else if (FieldExists($table, "networkports_id")) {
         // for glpi_networking_vlan
         $Sql = "SELECT `$table`.*
                 FROM `glpi_networkports`
                 INNER JOIN `$table` ON (`glpi_networkports`.`id` = `$table`.`networkports_id`)
                 WHERE (`glpi_networkports`.`entities_id` $entity_in)";

      } else if (FieldExists($table, "groups_id")) {
         // glpi_users_groups
         $Sql .= "WHERE `groups_id` IN (SELECT `id`
                                        FROM `glpi_groups`
                                        WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "suppliers_id")) {
         // For glpi_contact_enterprise and glpi_contract_enterprise
         $Sql .= "WHERE `suppliers_id` IN (SELECT `id`
                                           FROM `glpi_suppliers`
                                           WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "contracts_id")) {
         // For glpi_contract_device (or glpi_contract_enterprise)
         $Sql .= "WHERE `contracts_id` IN (SELECT `id`
                                           FROM `glpi_contacts`
                                           WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "printers_id")) {
         // For glpi_cartridges
         $Sql .= "WHERE `printers_id` IN (SELECT `id`
                                          FROM `glpi_printers`
                                          WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "computers_id")) {
         // For glpi_computers_softwarelicences, volumes, ...
         $Sql = "SELECT `$table`.*
                 FROM `glpi_computers`
                 INNER JOIN `$table` ON (`glpi_computers`.`id` = `$table`.`computers_id`)
                 WHERE (`glpi_computers`.`entities_id` $entity_in)";

      } else if (FieldExists($table, "calendars_id")) {
         // For glpi_calendars_holidays
         $Sql .= "WHERE `calendars_id` IN (SELECT `id`
                                           FROM `glpi_calendars`
                                           WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "changes_id")) {
         // For glpi_changes_groups, glpi_changes_items, glpi_changes_problems, glpi_changes_tickets,
         // glpi_changes_users, glpi_changetasks
         $Sql .= "WHERE `changes_id` IN (SELECT `id`
                                         FROM `glpi_changes`
                                         WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "problems_id")) {
         // For glpi_items_problems, glpi_problems_tickets, glpi_problems_users, glpi_problemtasks
         $Sql .= "WHERE `problems_id` IN (SELECT `id`
                                          FROM `glpi_problems`
                                          WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "links_id")) {
         // For glpi_links_itemtypes
         $Sql .= "WHERE `links_id` IN (SELECT `id`
                                       FROM `glpi_links`
                                       WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "reservationitems_id")) {
         // For glpi_reservations
         $Sql .= "WHERE `reservationitems_id` IN (SELECT `id`
                                                  FROM `glpi_reservationitems`
                                                  WHERE `entities_id` $entity_in)";

      } else if (FieldExists($table, "tickets_id")) {
         // For glpi_ticketfollowups, glpi_ticketsatisfactions, glpi_tickets_tickets,
         // glpi_tickets_users, glpi_tickettasks
         $Sql .= "WHERE `tickets_id` IN (SELECT `id`
                                         FROM `glpi_tickets`
                                         WHERE `entities_id` $entity_in)";


      } else if (FieldExists($table, "id")) {
         // Global tables like dropdown
         $Sql .= " ORDER BY `id";
      }

      $result = $DB->query($Sql);
      if (!$result) {
         return false;
      }

      $ficname = PLUGIN_DUMPENTITY_UPLOAD_DIR."$entity-$table.csv";
      if ($gzip) {
         $fic = gzopen($ficname, "wb");
      } else {
         $fic = fopen($ficname, "wb");
      }

      if (!$fic) {
         return false;
      }

      if ($data = $DB->fetch_assoc($result)) {
         $str = "";
         foreach ($data as $nom=>$val) {
            if (!empty($str)) {
               $str .= ";";
            }
            $str .= '"' . $nom . '"';
         }
         if ($gzip) {
            gzwrite($fic, $str . "\r\n");
         } else {
            fwrite($fic, $str . "\r\n");
         }
         do {
            $str = "";
            foreach ($data as $nom => $val) {
               if (!empty($str)) {
                  $str.=";";
               }

               if ($val == NULL) {
                  $str .= "NULL";
               } else if (is_numeric($val)) {
                  $str .= $val;
               } else if (!empty($val)) {
                  if ($encode) {
                     $val = Toolbox::decodeFromUtf8($val, $encode);
                  }
                  $str .= '"' . mysql_real_escape_string($val) . '"';
               }
            }
            if ($gzip) {
               gzwrite($fic, $str . "\r\n");
            } else {
               fwrite($fic, $str . "\r\n");
            }
         } while ($data = $DB->fetch_assoc($result));
      }

      if ($gzip) {
         gzclose($fic);
      } else {
         fclose($fic);
      }

      return $ficname;
   }

   static function parents ($entity) {

      $parents = getAncestorsOf("glpi_entities", $entity);
      $list    = "($entity";
      foreach ($parents as $parent) {
       $list .= ", $parent";
      }
      return $list.")";
   }
}
