<?php
/*
 * @version $Id: profile.class.php 124 2012-07-04 12:29:03Z remi $
 -------------------------------------------------------------------------
 dumpentity - DumpEntity plugin for GLPI
 Copyright (C) 2003-2011 by the dumpentity Development Team.

 https://forge.indepnet.net/projects/dumpentity
 -------------------------------------------------------------------------

 LICENSE

 This file is part of dumpentity.

 dumpentity is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 dumpentity is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with dumpentity. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
*/

// Original Author of file: Remi Collet & Nelly LASSON
// Purpose of file:
// ----------------------------------------------------------------------

if (!defined('GLPI_ROOT')) {
   die("Sorry. You can't access directly to this file");
}

class PluginDumpentityProfile extends CommonDBTM{


   //if profile deleted
   static function cleanProfile(Profile $prof) {

      $plugprof = new self();
      if ($plugprof->getFromDBForProfile($prof->getField("id"))) {
         $plugprof->delete(array('id' => $plugprof->fields['id']));
      }
   }


   static function select() {

      $prof = new self();
//      if (TableExists("glpi_plugin_dumpentity_models")) {
      if ($prof->getFromDBForProfile($_SESSION['glpiactiveprofile']['id'])
          && $prof->fields['models_id'] > 0) {
         $_SESSION["glpi_plugin_dumpentity_profile"] = $prof->fields;
      } else {
          unset($_SESSION["glpi_plugin_dumpentity_profile"]);
      }
//      }
   }


   function getFromDBForProfile($ID){
      global $DB;

      $ID_profile = 0;
      // Get user profile
      $query = "SELECT `id`
                FROM `glpi_plugin_dumpentity_profiles`
                WHERE `profiles_id` = '$ID'";

      if ($result = $DB->query($query)) {
         if ($DB->numrows($result)) {
            $ID_profile = $DB->result($result,0,0);
         }
      }

      if ($ID_profile) {
         return $this->getFromDB($ID_profile);
      }
      return false;
   }


   function createaccess($profile) {
      return $this->add(array('profiles_id' => $profile->getField('id')));
   }


   function showFormEdit($profID) {
      global $LANG,$DB;

      $target = $this->getFormURL();
      if (isset($options['target'])) {
        $target = $options['target'];
      }

      if (!Session::haveRight("profile","r")) {
         return false;
      }
      $canedit = Session::haveRight("profile","w");

      $this->getFromDBForProfile($profID);

      echo "<form action='".$target."' method='post'>";
      echo "<table class='tab_cadre' cellpadding='5'>";
      echo "<tr><th colspan='2'>".$LANG['plugin_dumpentity']["config"][9]." '".
      Dropdown::getDropdownName('glpi_profiles',$profID)."' </th></tr>";

      echo "<tr class='tab_bg_1'><td>" . $LANG['plugin_dumpentity']["config"][1] . "&nbsp:</td><td>";
      Dropdown::show('PluginDumpentityModel',
                     array('name'     => 'models_id',
                           'value'    => $this->fields["models_id"],
                           'comments' => true));
      echo "</td></tr>\n";

      if ($canedit) {
         echo "<tr class='tab_bg_1'><td class='center' colspan='2'>";
         echo "<input type='hidden' name='id' value='".$this->fields["id"]."'>";
         echo "<input type='submit' name='update_user_profile' value='".
               $LANG["buttons"][7]."' class='submit'>&nbsp;&nbsp;";
         echo "</td></tr>\n";
      }

      echo "</table>";
      if ($canedit) {
         Html::closeForm();
      }
   }


   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
      global $LANG;

      if ($item->getType() == 'Profile') {
         if ($item->getField('id') && $item->getField('interface')!='helpdesk') {
            return array(1 => $LANG['plugin_dumpentity']['setup'][1]);
         }
      }
      if ($item->getType() == 'PluginDumpentityModel') {
            if ($_SESSION['glpishow_count_on_tabs']) {
               $nb = countElementsInTable($this->getTable(), "`models_id`=".$item->getID());
               return self::createTabEntry($LANG['Menu'][35], $nb);
            }
         return $LANG['Menu'][35];
      }
      return '';
   }


   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {

      if ($item->getType() == 'Profile') {
         $prof = new self();
         $ID = $item->getField('id');
         if (!$prof->getFromDBForProfile($ID)) {
            $prof->createAccess($item);
         }
         $prof->showFormEdit($ID);
      } else if ($item->getType()=='PluginDumpentityModel') {
         self::showForModel($item);
      } else {
         return false;
      }
      return true;
   }


   static function showForModel(PluginDumpentityModel $model) {
      global $DB, $LANG;

      $plugprof = new self();
      echo "<div class='center'><table class='tab_cadre_fixe'>";

      $prof = new Profile();
      $req = $DB->request($plugprof->getTable(), array('models_id' => $model->getID()));
      if ($req->numrows()) {
         echo "<tr><th>".$LANG['common'][16]."</th></tr>";

         Session::initNavigateListItems('Profile', $model->getTypeName(1)." = ".$model->getName());

         foreach ($req as $data) {
            if ($prof->getFromDB($data['profiles_id'])) {
               Session::addToNavigateListItems('Profile', $data['profiles_id']);

               echo "<tr class='tab_bg_1'><td>";
               echo $prof->getLink(true);
               echo "</td></tr>";
            }
         }
      } else  {
         echo "<tr><th>".$LANG['stats'][2]."</td></tr>";
      }
      echo "</table>";
   }
}
